summaryrefslogtreecommitdiff
path: root/config.default.php
diff options
context:
space:
mode:
Diffstat (limited to 'config.default.php')
-rw-r--r--config.default.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/config.default.php b/config.default.php
index 31849160..c9a387e0 100644
--- a/config.default.php
+++ b/config.default.php
@@ -10,8 +10,8 @@ define('DATA_DIR', __DIR__.DIRECTORY_SEPARATOR.'data');
// Enable/Disable debug
define('DEBUG', false);
-// Available log drivers: syslog, stderr, stdout or file
-define('LOG_DRIVER', '');
+// Available log drivers: syslog, stderr, stdout, system or file
+define('LOG_DRIVER', 'system');
// Log filename if the log driver is "file"
define('LOG_FILE', DATA_DIR.DIRECTORY_SEPARATOR.'debug.log');